;; (C) Copyright Collin J. Doering 2014
;;
;; This program is free software: you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;; 
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;; 
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;; File: custom.el
;; Author: Collin J. Doering <collin.doering@rekahsoft.ca>
;; Date: Nov 12, 2014

;; This file is for emacs customize variables, etc.. only!

(custom-set-variables
 ;; custom-set-variables was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(TeX-command-list
   (quote
    (("TeX" "%(PDF)%(tex) %`%S%(PDFout)%(mode)%' %t" TeX-run-TeX nil
      (plain-tex-mode texinfo-mode ams-tex-mode)
      :help "Run plain TeX")
     ("LaTeX" "%`%l%(mode)%' %t" TeX-run-TeX nil
      (latex-mode doctex-mode)
      :help "Run LaTeX")
     ("Makeinfo" "makeinfo %t" TeX-run-compile nil
      (texinfo-mode)
      :help "Run Makeinfo with Info output")
     ("Makeinfo HTML" "makeinfo --html %t" TeX-run-compile nil
      (texinfo-mode)
      :help "Run Makeinfo with HTML output")
     ("AmSTeX" "%(PDF)amstex %`%S%(PDFout)%(mode)%' %t" TeX-run-TeX nil
      (ams-tex-mode)
      :help "Run AMSTeX")
     ("ConTeXt" "texexec --once --texutil %(execopts)%t" TeX-run-TeX nil
      (context-mode)
      :help "Run ConTeXt once")
     ("ConTeXt Full" "texexec %(execopts)%t" TeX-run-TeX nil
      (context-mode)
      :help "Run ConTeXt until completion")
     ("BibTeX" "bibtex %s" TeX-run-BibTeX nil t :help "Run BibTeX")
     ("Biber" "biber %s" TeX-run-Biber nil t :help "Run Biber")
     ("View" "zathura %s.pdf" TeX-run-discard-or-function t t :help "Run Viewer")
     ("Print" "%p" TeX-run-command t t :help "Print the file")
     ("Queue" "%q" TeX-run-background nil t :help "View the printer queue" :visible TeX-queue-command)
     ("File" "%(o?)dvips %d -o %f " TeX-run-command t t :help "Generate PostScript file")
     ("Index" "makeindex %s" TeX-run-command nil t :help "Create index file")
     ("Check" "lacheck %s" TeX-run-compile nil
      (latex-mode)
      :help "Check LaTeX file for correctness")
     ("Spell" "(TeX-ispell-document \"\")" TeX-run-function nil t :help "Spell-check the document")
     ("Clean" "TeX-clean" TeX-run-function nil t :help "Delete generated intermediate files")
     ("Clean All" "(TeX-clean t)" TeX-run-function nil t :help "Delete generated intermediate and output files")
     ("Other" "" TeX-run-command t t :help "Run an arbitrary command"))))
 '(bmkp-last-as-first-bookmark-file "/home/collin/.emacs.d/bookmarks")
 '(coffee-tab-width 2)
 '(confirm-kill-emacs (quote y-or-n-p))
 '(custom-safe-themes
   (quote
    ("96b54f35e473769a388f12984d735092f9163c63aa6724ee49176d865c46071b" "fc5fcb6f1f1c1bc01305694c59a1a861b008c534cae8d0e48e4d5e81ad718bc6" "b5aaedbcd4d81925c8b2bc21dbed6d0a5a6854b6ad745e948efd55e42b48bd04" "8aebf25556399b58091e533e455dd50a6a9cba958cc4ebb0aab175863c25b9a4" "36a309985a0f9ed1a0c3a69625802f87dee940767c9e200b89cdebdb737e5b29" "dc8693659115ea453f849f47509b903da3801b5f1521a73fa31556a9a3558517" default)))
 '(fill-column 95)
 '(geiser-default-implementation (quote racket))
 '(geiser-racket-collects (quote ("/usr/share/racket/collects")))
 '(hl-sexp-background-color "#19202B")
 '(ido-enable-flex-matching t)
 '(ix-token (quote linlin3thawin))
 '(ix-user (quote rkd))
 '(magit-commit-signoff t t)
 '(mpc-host "patchMeIn@localhost")
 '(quack-default-program "racket")
 '(quack-fontify-style (quote plt))
 '(quack-programs
   (quote
    ("mzscheme" "bigloo" "csi" "csi -hygienic" "gosh" "gracket" "gsi" "gsi ~~/syntax-case.scm -" "guile" "kawa" "mit-scheme" "racket" "racket -il typed/racket" "rs" "scheme" "scheme48" "scsh" "sisc" "stklos" "sxi")))
 '(quack-remap-find-file-bindings-p nil)
 '(rcirc-authinfo
   (quote
    (("irc.freenode.net" nickserv "rekahsoft" "linux:netbeans")
     ("localhost" bitlbee "rekahsoft" "linux:netbeans"))))
 '(rcirc-kill-channel-buffers t)
 '(scroll-bar-mode nil)
 '(send-mail-function (quote smtpmail-send-it))
 '(show-paren-mode t)
 '(use-package-verbose t)
 '(w3m-content-type-alist
   (quote
    (("text/plain" "\\.\\(?:txt\\|tex\\|el\\)\\'" nil nil)
     ("text/html" "\\.s?html?\\'"
      ("conkeror" file)
      nil)
     ("text/sgml" "\\.sgml?\\'" nil "text/plain")
     ("text/xml" "\\.xml\\'" nil "text/plain")
     ("image/jpeg" "\\.jpe?g\\'"
      ("/usr/bin/display" file)
      nil)
     ("image/png" "\\.png\\'"
      ("/usr/bin/display" file)
      nil)
     ("image/gif" "\\.gif\\'"
      ("/usr/bin/display" file)
      nil)
     ("image/tiff" "\\.tif?f\\'"
      ("/usr/bin/display" file)
      nil)
     ("image/x-xwd" "\\.xwd\\'"
      ("/usr/bin/display" file)
      nil)
     ("image/x-xbm" "\\.xbm\\'"
      ("/usr/bin/display" file)
      nil)
     ("image/x-xpm" "\\.xpm\\'"
      ("/usr/bin/display" file)
      nil)
     ("image/x-bmp" "\\.bmp\\'"
      ("/usr/bin/display" file)
      nil)
     ("video/mpeg" "\\.mpe?g\\'" nil nil)
     ("video/quicktime" "\\.mov\\'" nil nil)
     ("application/dvi" "\\.dvi\\'"
      ("xdvi" file)
      nil)
     ("application/postscript" "\\.e?ps\\'"
      ("gs" file)
      nil)
     ("application/pdf" "\\.pdf\\'" nil nil)
     ("application/x-pdf" "\\.pdf\\'" nil nil)
     ("application/xml" "\\.xml\\'" nil w3m-detect-xml-type)
     ("application/rdf+xml" "\\.rdf\\'" nil "text/plain")
     ("application/rss+xml" "\\.rss\\'" nil "text/plain")
     ("application/xhtml+xml" nil nil "text/html"))))
 '(yas-prompt-functions (quote (shk-yas/helm-prompt))))
(custom-set-faces
 ;; custom-set-faces was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(window-number-face ((t (:background "grey10"))) t))
(put 'dired-find-alternate-file 'disabled nil)
(put 'downcase-region 'disabled nil)
